==> ev_framework-0.0.5.tar.gz: lib/Elves/Widget/Ev_Api_Widget.dart <==
import '../API/Ev_API.dart';
import 'package:flutter/material.dart';

import '../Elves.dart';

class $Ev_Api_Widget extends StatefulWidget {
  var url;
  var post;
  var loading_color;
  var api_result;
  $Ev_Item evdata;

  $Ev_Api_Widget(this.evdata, {this.url,this.post,this.api_result,this.loading_color = Colors.blue,Key key}): super(key: key){}


  @override
  _$Ev_Api_WidgetState createState() => _$Ev_Api_WidgetState();
}

class _$Ev_Api_WidgetState extends State<$Ev_Api_Widget> {

  Ev_API api = Ev_API();
  var loaded = false;
  var error = false;
  var sdata;
  var buildwidget;

  @override
  Widget build(BuildContext context) {
    if(error)
    {  return Error_Reload(context); }

    if(!loaded) {
      api.Post(widget.url, post: widget.post,alert_error: true,
          onSuccess: (Ev_API_Result result) {
            setState(() {
              sdata = result.sdata;
              loaded = true;
              error = false;
            });
          },
          onConnectError: () {
            setState(() {
              error = true;
              loaded = false;
            });
          },
          onReturnError:()
          {  setState((){
            error = true;
            loaded = false;
          });
          }
      );
      return Center(
          child: SizedBox(
              child:
              new CircularProgressIndicator(
                  valueColor: new AlwaysStoppedAnimation(Colors.blue),
                  strokeWidth: 5.0),
              height: 40.0,
              width: 40.0));
    }
    else
    {  if(buildwidget == null)
    {  buildwidget =  widget.api_result(sdata); }
    return buildwidget;
    }

  }

  Widget Error_Reload(BuildContext context)
  {  return Center(child: Column(
    mainAxisAlignment: MainAxisAlignment.center,
    children: <Widget>[
      Icon(Icons.error_outline,color: Colors.amber,size: 110),
      RaisedButton(child: Icon(Icons.refresh,size: 25,),onPressed: (){
        setState(() {
          error = false;
          loaded = false;
        });
      },)
    ],),);
  }

  @override
  void dispose() {
    // TODO: implement dispose
    api.Stop();
    super.dispose();
  }

  void reload(url,post)
  {   api.Stop();
  if(url != null)
  {  widget.url = url; }

  if(post != null)
  {  widget.post = post; }

  print("reload " + widget.url + " post " + widget.post.toString());
  setState(() {
    loaded = false;
    error = false;
    buildwidget = null;
  });

  }
}

==> ev_framework-2.0.4.tar.gz: lib/Elves/Widget/Ev_Api_Widget.dart <==
import '../API/Ev_API.dart';
import 'package:flutter/material.dart';

import '../Elves.dart';

class $Ev_Api_Widget extends StatefulWidget {
  var url;
  var post;
  var loading_color;
  var api_result;
  $Ev_Item evdata;

  $Ev_Api_Widget(this.evdata, {this.url,this.post,this.api_result,this.loading_color = Colors.blue,Key key}): super(key: key){}


  @override
  _$Ev_Api_WidgetState createState() => _$Ev_Api_WidgetState();
}

class _$Ev_Api_WidgetState extends State<$Ev_Api_Widget> {

  Ev_API api = Ev_API();
  var loaded = false;
  var error = false;
  var sdata;
  var buildwidget;

  @override
  Widget build(BuildContext context) {
    if(error)
    {  return Error_Reload(context); }

    if(!loaded) {
      api.Post(widget.url, post: widget.post,alert_error: true,
          onSuccess: (Ev_API_Result result) {
            setState(() {
              sdata = result.sdata;
              loaded = true;
              error = false;
            });
          },
          onConnectError: () {
            setState(() {
              error = true;
              loaded = false;
            });
          },
          onReturnError:()
          {  setState((){
            error = true;
            loaded = false;
          });
          }
      );
      return Center(
          child: SizedBox(
              child:
              new CircularProgressIndicator(
                  valueColor: new AlwaysStoppedAnimation(Colors.blue),
                  strokeWidth: 5.0),
              height: 40.0,
              width: 40.0));
    }
    else
    {  if(buildwidget == null)
         {  buildwidget =  widget.api_result(context,sdata); }
    return buildwidget;
    }

  }

  Widget Error_Reload(BuildContext context)
  {  return Center(child: Column(
    mainAxisAlignment: MainAxisAlignment.center,
    children: <Widget>[
      Icon(Icons.error_outline,color: Colors.amber,size: 110),
      RaisedButton(child: Icon(Icons.refresh,size: 25,),onPressed: (){
        setState(() {
          error = false;
          loaded = false;
        });
      },)
    ],),);
  }

  @override
  void dispose() {
    // TODO: implement dispose
    api.Stop();
    super.dispose();
  }

  void reload(url,post)
  {   api.Stop();
  if(url != null)
  {  widget.url = url; }

  if(post != null)
  {  widget.post = post; }

  print("reload " + widget.url + " post " + widget.post.toString());
  setState(() {
    loaded = false;
    error = false;
    buildwidget = null;
  });

  }
}
